@@ -337,21 +337,21 @@ get.likelihood.seqTrack <- function(x, mu, haplo.length,...){
 ##########################
 ## as("seqTrack", "graphNEL")
 ##########################
-if(require(graph)){
-setOldClass("seqTrack")
-setAs("seqTrack", "graphNEL", def=function(from){
-    ##    if(!require(ape)) stop("package ape is required")
-    if(!require(graph)) stop("package graph is required")
+## if(require(graph)){
+## setOldClass("seqTrack")
+## setAs("seqTrack", "graphNEL", def=function(from){
+##     ##    if(!require(ape)) stop("package ape is required")
+##     if(!require(graph)) stop("package graph is required")
 
-    ori.labels <- rownames(from)
-    from <- from[!is.na(from$ances),,drop=FALSE]
+##     ori.labels <- rownames(from)
+##     from <- from[!is.na(from$ances),,drop=FALSE]
 
 
-     ## CONVERT TO GRAPH
-    res <- ftM2graphNEL(ft=cbind(ori.labels[from$ances], ori.labels[from$id]), W=from$weight, edgemode = "directed", V=ori.labels)
-    return(res)
-})
-}
+##      ## CONVERT TO GRAPH
+##     res <- ftM2graphNEL(ft=cbind(ori.labels[from$ances], ori.labels[from$id]), W=from$weight, edgemode = "directed", V=ori.labels)
+##     return(res)
+## })
+## }
 
 
 
